'use strict';

var _tape = require('tape');

var _tape2 = _interopRequireDefault(_tape);

var _immutable = require('immutable');

var _map = require('../map');

var _utils = require('../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var nestedMaps = (0, _immutable.fromJS)({
		a: {
				b: "B",
				c: "C",
				d: {
						e: "E"
				}
		},
		f: "F"
});

var childLists = (0, _immutable.fromJS)({
		name: "root",
		children: [{
				name: "child 1",
				children: [{ name: "grandchild 1" }, { name: "grandchild 2" }]
		}, {
				name: "child 2",
				children: []
		}, { name: "child 3" }]
});

(0, _tape2.default)('deepMap', function (test) {
		test.plan(2);

		test.ok((0, _immutable.is)(childLists.update((0, _map.deepMap)(function (item) {
				return item.set('abc', 123);
		}, ['children'])), (0, _immutable.fromJS)({
				name: "root",
				abc: 123,
				children: [{
						name: "child 1",
						abc: 123,
						children: [{ name: "grandchild 1", abc: 123 }, { name: "grandchild 2", abc: 123 }]
				}, {
						name: "child 2",
						abc: 123,
						children: []
				}, { name: "child 3", abc: 123 }]
		})), 'deepMap iterates through every node using a childPath');

		test.ok((0, _immutable.is)(nestedMaps.update((0, _map.deepMap)(function (item) {
				// normally deepMap on trees that don't require childPaths is a bit pointless
				// because you'll almost certainly have to deal with leaves and parents differently
				return (0, _utils.isLeaf)(item) ? item + "!" : item.set('abc', 123);
		})), (0, _immutable.fromJS)({
				a: {
						b: "B!",
						c: "C!",
						d: {
								e: "E!",
								abc: 123
						},
						abc: 123
				},
				f: "F!",
				abc: 123
		})), 'deepMap iterates through every node without using a childPath (kind of pointless)');
});

(0, _tape2.default)('deepMapLeaves', function (test) {
		test.plan(2);

		test.ok((0, _immutable.is)(childLists.update((0, _map.deepMapLeaves)(function (item) {
				return item.set('abc', 123);
		}, ['children'])), (0, _immutable.fromJS)({
				name: "root",
				children: [{
						name: "child 1",
						children: [{ name: "grandchild 1", abc: 123 }, { name: "grandchild 2", abc: 123 }]
				}, {
						name: "child 2",
						abc: 123,
						children: []
				}, { name: "child 3", abc: 123 }]
		})), 'deepMapLeaves iterates through only leaves when using a childPath');

		test.ok((0, _immutable.is)(nestedMaps.update((0, _map.deepMapLeaves)(function (item) {
				return item + "!";
		})), (0, _immutable.fromJS)({
				a: {
						b: "B!",
						c: "C!",
						d: {
								e: "E!"
						}
				},
				f: "F!"
		})), 'deepMapLeaves iterates through only leaves when not using a childPath');
});

(0, _tape2.default)('deepMapParents', function (test) {
		test.plan(2);

		test.ok((0, _immutable.is)(childLists.update((0, _map.deepMapParents)(function (item) {
				return item.set('abc', 123);
		}, ['children'])), (0, _immutable.fromJS)({
				name: "root",
				abc: 123,
				children: [{
						name: "child 1",
						abc: 123,
						children: [{ name: "grandchild 1" }, { name: "grandchild 2" }]
				}, {
						name: "child 2",
						children: []
				}, { name: "child 3" }]
		})), 'deepMapParents iterates through every parent node using a childPath');

		test.ok((0, _immutable.is)(nestedMaps.update((0, _map.deepMapParents)(function (item) {
				return item.set('abc', 123);
		})), (0, _immutable.fromJS)({
				a: {
						b: "B",
						c: "C",
						d: {
								e: "E",
								abc: 123
						},
						abc: 123
				},
				f: "F",
				abc: 123
		})), 'deepMapParents iterates through every parent node without using a childPath');
});