import tape from 'tape';
import {
  is,
  fromJS,
  Iterable,
  List,
  Map,
  OrderedMap
} from 'immutable';

import {
  deepSet,
  deepSetChildren
} from '../set';

const nestedMaps = fromJS({
  a: {
    b: "B"
  },
  f: "F"
});

const childLists = fromJS({
  name: "root",
  children: [
    {
      name: "child 1",
      children: [
        {name: "grandchild 1"},
        {name: "grandchild 2"}
      ]
    }
  ]
});

tape('deepSet', test => {
    test.plan(2);

    test.ok(is(
    	nestedMaps.update(deepSet(['a','b'], "new value")),
    	fromJS({
		  a: {
		    b: "new value"
		  },
		  f: "F"
		})
    ), 'using no childPath works like setIn');

    test.ok(is(
      childLists.update(deepSet([0,0], fromJS({name: "new name"}), ['children'])),
      fromJS({
	    name: "root",
	    children: [
	      {
	        name: "child 1",
	        children: [
	          {name: "new name"},
	          {name: "grandchild 2"}
	        ]
	      }
	    ]
	  })
    ), 'using childPath works correctly');
});

tape('deepSetChildren', test => {
    test.plan(2);

    test.ok(is(
    	nestedMaps.update(deepSetChildren(['f'], fromJS({x:"X", y:"Y"}))),
    	fromJS({
		  a: {
		    b: "B"
		  },
		  f: {
		  	x: "X",
		  	y: "Y"
		  }
		})
    ), 'using no childPath works like setIn');

    test.ok(is(
      childLists.update(deepSetChildren([0], fromJS([{name: "aaa"}]), ['children'])),
      fromJS({
	    name: "root",
	    children: [
	      {
	        name: "child 1",
	        children: [
	          {name: "aaa"}
	        ]
	      }
	    ]
	  })
    ), 'using childPath works correctly');
});